/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2013 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/

var BioMaterialLists = function()
{
	var biomateriallists = {};
	var selectedItemsInParentForm;
	
	/**
		Initialize the page.
	*/
	biomateriallists.initPage = function()
	{
		var pageId = Doc.getPageId();
		if (pageId == 'edit-page')
		{
			// Save + Close buttons
			Buttons.addClickHandler('btnSave', biomateriallists.save);
			Buttons.addClickHandler('close', App.closeWindow);

			// Tab validation
			TabControl.addTabValidator('settings.info', biomateriallists.validateList);
			TabControl.addTabActivateListener('settings.annotations', Annotations.autoLoadEditFrame);
			
			var frm = document.forms['list'];
			if (frm.source)
			{
				// Create biomaterial list from selection of biomaterials
				var parentForm = Data.get('sourceSelected', 'parent-form');
				selectedItemsInParentForm = window.opener.Table.getSelected(parentForm)
				var lblSelected = Doc.element('lblSelected');
				if (selectedItemsInParentForm.length == 0)
				{
					frm.source[0].disabled = true;
				}
				else
				{
					Forms.checkRadio(frm.source, 'selected');
					lblSelected.innerHTML += ' ['+selectedItemsInParentForm.length+']';
				}
			}
			
			if (Doc.element('minCount'))
			{
				Events.addEventHandler('minCount', 'keypress', Events.integerOnly);
				Events.addEventHandler('minCount', 'focus', biomateriallists.selectCreateCount);
			}

		}
		else if (pageId == 'view-page')
		{
			var itemId = Data.get('page-data', 'item-id');
			var attributes = {'item-type': 'BIOMATERIALLIST', 'item-id': itemId};
			Buttons.addClickHandler('btnEdit', Buttons.editItem, attributes);
			Buttons.addClickHandler('btnDelete', Buttons.deleteItem, attributes);
			Buttons.addClickHandler('btnRestore', Buttons.restoreItem, attributes);
			Buttons.addClickHandler('btnUsingItems', Buttons.showUsingItems, attributes);
			Buttons.addClickHandler('btnDeletePermanently', Buttons.deleteItemPermanently, attributes);
			Buttons.addClickHandler('btnShare', Buttons.shareItem, attributes);
			Buttons.addClickHandler('btnSetOwner', Buttons.setOwner, attributes);
			Buttons.addClickHandler('btnExport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnImport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnPlaceOnPlate', biomateriallists.placeOnPlateOnClick);
			Buttons.addClickHandler('btnMergeUnion', biomateriallists.mergeOnClick);
			Buttons.addClickHandler('btnMergeIntersection', biomateriallists.mergeOnClick);
			Buttons.addClickHandler('btnMergeComplement', biomateriallists.mergeOnClick);
			
			TabControl.addTabActivateListener('main.annotations', AnnotationsList.loadOnce);
			TabControl.addTabActivateListener('main.overview', Overview.loadOnce);
			TabControl.addTabActivateListener('main.members', biomateriallists.viewMembers);
			TabControl.addTabActivateListener('main.history', History.loadOnce);
		}
		else if (pageId == 'list-page')
		{
			var attributes = {'item-type': 'BIOMATERIALLIST'};
			var tableAttributes = {'table-id': 'lists'};
			Buttons.addClickHandler('btnNewItem', biomateriallists.newItem, attributes);
			Buttons.addClickHandler('btnDeleteItems', Buttons.deleteItems, tableAttributes);
			Buttons.addClickHandler('btnRestoreItems', Buttons.restoreItems, tableAttributes);
			Buttons.addClickHandler('btnShareItems', Buttons.shareItems, tableAttributes);
			Buttons.addClickHandler('btnSetOwner', Buttons.setOwnerOfItems, tableAttributes);
			Buttons.addClickHandler('btnColumns', Buttons.configureColumns, tableAttributes);
			Buttons.addClickHandler('btnExport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnImport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runListPlugin, tableAttributes);

			Buttons.addClickHandler('close', App.closeWindow);
			Buttons.addClickHandler('btnOk', Buttons.returnSelected, tableAttributes);
		}
	}
	
	biomateriallists.newItem = function()
	{
		var controller = Items.getController('BIOMATERIALLIST');
		Table.submitToPopup('lists', 'NewItem', controller.width, controller.height);
	}
	
	biomateriallists.viewMembers = function()
	{
		var listId = Data.get('page-data', 'item-id');
		var url = 'members/index.jsp?ID='+App.getSessionId();
		url += '&cmd=List&list_id='+listId;
		location.replace(url);
	}
	
	biomateriallists.placeOnPlateOnClick = function()
	{
		var listId = Data.get('page-data', 'item-id');
		var url = 'members/index.jsp?ID='+App.getSessionId();
		url += '&cmd=PlaceOnPlate&list_id='+listId;
		Dialogs.openPopup(url, 'PlaceOnPlate', 900, 600);
	}
	
	biomateriallists.mergeOnClick = function(event)
	{
		var target = event.currentTarget;
		var mergeType = Data.get(target, 'merge-type');
		var listId = Data.get('page-data', 'item-id');
		
		var url = 'merge.jsp?ID='+App.getSessionId();
		url += '&item_id='+listId;
		url += '&mergeType='+mergeType;
		
		Dialogs.openPopup(url, 'Merge', 600, 400);
	}

	biomateriallists.validateList = function()
	{
		var frm = document.forms['list'];
		if (Strings.trim(frm.name.value) == '')
		{
			Forms.showNotification(frm.name, 'You must enter a name');
			return false;
		}
		return true;
	}

	// Submit the form
	biomateriallists.save = function()
	{
		var frm = document.forms['list'];
		if (TabControl.validateActiveTab('settings'))
		{
			Annotations.saveModifiedAnnotationsToForm(frm);
			if (selectedItemsInParentForm)
			{
				Forms.addHidden(frm, 'items', selectedItemsInParentForm.join(','));
			}
			frm.memberType.disabled = false;
			frm.submit();
		}
	}
	
	biomateriallists.selectCreateCount = function()
	{
		var frm = document.forms['list'];
		Forms.checkRadio(frm.create, 'count');
	}
	
	
	return biomateriallists;
}();

Doc.onLoad(BioMaterialLists.initPage);
