<%-- $Id: list_trash.jsp 6604 2014-11-18 10:39:22Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg, Martin Svensson
	Copyright (C) 2007 Johan Enell, Nicklas Nordborg, Martin Svensson

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
	@version 2.0
--%>
<%@ page pageEncoding="UTF-8" session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.Trashcan"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.BasicItem"
	import="net.sf.basedb.core.Removable"
	import="net.sf.basedb.core.Nameable"
	import="net.sf.basedb.core.File"
	import="net.sf.basedb.core.Directory"
	import="net.sf.basedb.core.Metadata"
	import="net.sf.basedb.core.query.ResultList"
	import="net.sf.basedb.util.Enumeration"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.util.HTML"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.clients.web.extensions.ExtensionsControl"
	import="net.sf.basedb.clients.web.extensions.JspContext"
	import="net.sf.basedb.clients.web.extensions.renderer.PrefixSuffixRenderer"
	import="net.sf.basedb.clients.web.extensions.toolbar.ToolbarUtil"
	import="net.sf.basedb.clients.web.extensions.list.ListColumnUtil"
	import="net.sf.basedb.util.extensions.ExtensionsInvoker"
	import="java.util.Set"
	import="java.util.HashSet"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="tbl" uri="/WEB-INF/table.tld" %>
<%@ taglib prefix="ext" uri="/WEB-INF/extensions.tld" %>
<%!
	private static final Item itemType = Item.SYSTEM;
	private static final String subContext = "trashcan";

	private static final Enumeration<String, String> items = new Enumeration<String, String>();
	static
	{
		for (Item item : Metadata.getRemovableItems())
		{
			items.add(item.name(), item.toString());
		}
	}
%>
<%
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final String ID = sc.getId();
final ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, subContext, null, null);

final DbControl dc = sc.newDbControl();
ResultList<Removable> trash = null;
try
{
	long totalCount = 0;
	try
	{
		String filterItem = cc.getPropertyValue("type");
		Set<Item> itemTypes = null; 
		if (filterItem != null)
		{
			itemTypes = new HashSet<Item>();
			for (String name : filterItem.split("\\|"))
			{
				itemTypes.add(Item.valueOf(name));
			}
		}
		trash = Trashcan.getItems(dc, itemTypes, cc.getPage() * cc.getRowsPerPage(), cc.getRowsPerPage());
		totalCount = trash.getTotalCount();
	}
	catch (Throwable t)
	{
		cc.setMessage(t.getMessage());
	}
	int numListed = 0;
	JspContext jspContext = ExtensionsControl.createContext(dc, pageContext);
	ExtensionsInvoker invoker = ExtensionsControl.useExtensions(jspContext,  
			"net.sf.basedb.clients.web.toolbar.list.all", 
			"net.sf.basedb.clients.web.toolbar.list.trashcan");
	ExtensionsInvoker columnsInvoker =  ExtensionsControl.useExtensions(jspContext, 
			"net.sf.basedb.clients.web.listcolumn.trashcan");
	%>
	<base:page title="Trashcan" id="list-page">
	<base:head scripts="table.js,~trash.js" styles="table.css,toolbar.css">
		<ext:scripts context="<%=jspContext%>" />
		<ext:stylesheets context="<%=jspContext%>" />
	</base:head>
	
	<base:body>
		<h1>Trashcan</h1>
		<div class="content">
		<tbl:table 
			id="trashcan" 
			columns="<%=cc.getSetting("columns")%>"
			action="index.jsp"
			sc="<%=sc%>"
			item="<%=itemType%>"
			subcontext="<%=subContext%>"
			subclass="fulltable"
			>
			<tbl:columndef
				id="type"
				property="type"
				datatype="string"
				title="Item type"
				enumeration="<%=items%>"
				filterable="true"
				show="always"
			/>
			<tbl:columndef 
				id="name"
				title="Name"
				show="always" 
			/>
			<tbl:columndef
				id="id"
				property="id"
				datatype="int"
				title="ID"
				exportable="true"
			/>
			<tbl:columndef 
				id="description"
				title="Description"
			/>
			<tbl:columndef 
				id="xt-columns" 
				extensions="<%=columnsInvoker%>" 
				jspcontext="<%=jspContext%>" 
			/>
			<div class="panelgroup bg-filled-50 bottomborder">
				<tbl:toolbar subclass="bottomborder">
					<tbl:button
						id="btnDeleteAllItems"
						image="deleteall.png"
						title="Empty trash&hellip;"
						tooltip="Delete all items from the trashcan"
						disabled="<%=totalCount <= 0%>"
					/>
					<tbl:button 
						id="btnDeleteItems"
						image="delete_permanently.png"
						title="Delete permanently&hellip;" 
						tooltip="Delete the selected items permanently" 
						disabled="<%=totalCount <= 0%>"
					/>
					<tbl:button 
						id="btnRestoreItems"
						image="restore.png"
						title="Restore" 
						tooltip="Restore the selected items"
						disabled="<%=totalCount <= 0%>"
					/>
					<tbl:button 
						id="btnColumns"
						image="columns.png" 
						title="Columns&hellip;" 
						tooltip="Show, hide and re-order columns" 
					/>
					<ext:render extensions="<%=invoker%>" context="<%=jspContext%>" 
						wrapper="<%=new PrefixSuffixRenderer(jspContext, "<td>", "</td>") %>"/>
				</tbl:toolbar>
				<tbl:panel>
					<tbl:presetselector />
					<tbl:navigator
						page="<%=cc.getPage()%>" 
						rowsperpage="<%=cc.getRowsPerPage()%>" 
						totalrows="<%=trash == null ? 0 : trash.getTotalCount()%>"
					/>
				</tbl:panel>
			</div>
			<tbl:data>
				<tbl:headers>
					<tbl:headerrow>
						<tbl:header colspan="3" />
						<tbl:columnheaders />
					</tbl:headerrow>
					<tbl:headerrow>
						<tbl:header subclass="index" />
						<tbl:header 
							subclass="check" 
							><base:icon 
								id="check.uncheck"
								image="check_uncheck.png" 
								tooltip="Check/uncheck all" 
								data-regexp="item:"
							/></tbl:header>
						<tbl:header 
							subclass="icons" 
							/>
						<tbl:propertyfilter />
					</tbl:headerrow>
				</tbl:headers>
				<tbl:rows>
					<%
					if (cc.getMessage() != null)
					{
						%>
						<tbl:panel subclass="bg-filled-50">
							<div class="messagecontainer error"><%=cc.getMessage()%></div>
						</tbl:panel>
						<%
						cc.setMessage(null);
					}
					int index = cc.getPage()*cc.getRowsPerPage();
					if (trash != null)
					{
						for (Removable item : trash)
						{
							BasicItem basicItem = (BasicItem)item;
							boolean isUsed = basicItem.isUsed();
							int itemId = item.getId();
							String name = "";
							String description = "";
							if (item instanceof File)
							{
								File file = (File)item;
								name = file.getPath().toString();
								description = file.getDescription();
							}
							else if (item instanceof Directory)
							{
								Directory dir = (Directory)item;
								name = dir.getPath().toString();
								description = dir.getDescription();
							}
							else if (item instanceof Nameable)
							{
								Nameable nameable = (Nameable)item;
								name = nameable.getName();
								description = nameable.getDescription();
							}
							else
							{
								name = item.toString();
							}
							String link = Base.getLink(ID, HTML.encodeTags(name), item.getType(), itemId, true);
							index++;
							numListed++;
							%>
							<tbl:row>
								<tbl:header 
									clazz="index"
									><%=index%></tbl:header>
								<tbl:header 
									clazz="check" 
									><input 
										type="checkbox" 
										name="item:<%=item.getType().name()%>" 
										value="<%=itemId%>"
									></tbl:header>
								<tbl:header 
									clazz="icons" 
									><base:icon 
										subclass="link auto-init"
										data-auto-init="show-using-items"
										data-item-type="<%=item.getType().name() %>"
										data-item-id="<%=itemId %>"
										image="used.png"
										tooltip="This item is used by other items and cannot be deleted"
										visible="<%=isUsed%>"
									/>&nbsp;</tbl:header>
								<tbl:cell column="type"><%=item.getType()%></tbl:cell>
								<tbl:cell column="name"><%=link%></tbl:cell>
								<tbl:cell column="id"><%=item.getId()%></tbl:cell>
								<tbl:cell column="description"><%=HTML.encodeTags(description)%></tbl:cell>
								<tbl:xt-cells dc="<%=dc%>" item="<%=item%>">
									<tbl:cell column="xt-columns" />
								</tbl:xt-cells>
							</tbl:row>
							<%
							}
						}
					if (numListed == 0)
					{
						%>
						<tbl:panel subclass="bg-filled-50">
							<div class="messagecontainer note">
							<%=trash == null || trash.size() == 0 ? "No items were found" : "No items on this page. Please select another page!" %>
							</div>
						</tbl:panel>
						<%
					}
					%>
				</tbl:rows>
			</tbl:data>
		</tbl:table>
		</div>
		
	</base:body>
	</base:page>
	<%
}
finally
{
	if (dc != null) dc.close();
}
%>
